/*###############################################################################
# Linux Management Providers (LMP), Boot provider package
# Copyright (C) 2009 Nodir Nazarov <nazarov.nodir@gmail.com>
#
# This program is being developed under the "OpenDRIM" project.
# The "OpenDRIM" project web page: http://opendrim.sourceforge.net
# The "OpenDRIM" project mailing list: opendrim@googlegroups.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#################################################################################

#################################################################################
# To contributors, please leave your contact information in this section
# AND comment your changes in the source code.
#
# Modified by 2009 Guillaume BOTTEX, ETRI <guillaumebottex@etri.re.kr>
###############################################################################*/

#ifndef OPENDRIM_BOOTSERVICE_H_
#define OPENDRIM_BOOTSERVICE_H_

#include <Instance.h>

const static char* OpenDRIM_BootService_classnames[] = {"OpenDRIM_BootService"};
static string OpenDRIM_BootService_NAMESPACE = _NAMESPACE;

class OpenDRIM_BootService {

public:
	
	string InstanceID;
	bool InstanceID_isNULL;
	
	string Caption;
	bool Caption_isNULL;
	
	string Description;
	bool Description_isNULL;
	
	string ElementName;
	bool ElementName_isNULL;
	
	string InstallDate;
	bool InstallDate_isNULL;
	
	vector<unsigned short> OperationalStatus;
	bool OperationalStatus_isNULL;
	
	vector<string> StatusDescriptions;
	bool StatusDescriptions_isNULL;
	
	string Status;
	bool Status_isNULL;
	
	unsigned short HealthState;
	bool HealthState_isNULL;
	
	unsigned short CommunicationStatus;
	bool CommunicationStatus_isNULL;
	
	unsigned short DetailedStatus;
	bool DetailedStatus_isNULL;
	
	unsigned short OperatingStatus;
	bool OperatingStatus_isNULL;
	
	unsigned short PrimaryStatus;
	bool PrimaryStatus_isNULL;
	
	unsigned short EnabledState;
	bool EnabledState_isNULL;
	
	string OtherEnabledState;
	bool OtherEnabledState_isNULL;
	
	unsigned short RequestedState;
	bool RequestedState_isNULL;
	
	unsigned short EnabledDefault;
	bool EnabledDefault_isNULL;
	
	string TimeOfLastStateChange;
	bool TimeOfLastStateChange_isNULL;
	
	vector<unsigned short> AvailableRequestedStates;
	bool AvailableRequestedStates_isNULL;
	
	unsigned short TransitioningToState;
	bool TransitioningToState_isNULL;
	
	string SystemCreationClassName;
	bool SystemCreationClassName_isNULL;
	
	string SystemName;
	bool SystemName_isNULL;
	
	string CreationClassName;
	bool CreationClassName_isNULL;
	
	string Name;
	bool Name_isNULL;
	
	string PrimaryOwnerName;
	bool PrimaryOwnerName_isNULL;
	
	string PrimaryOwnerContact;
	bool PrimaryOwnerContact_isNULL;
	
	string StartMode;
	bool StartMode_isNULL;
	
	bool Started;
	bool Started_isNULL;
	
	OpenDRIM_BootService() {
		InstanceID_isNULL = true;
		Caption_isNULL = true;
		Description_isNULL = true;
		ElementName_isNULL = true;
		InstallDate_isNULL = true;
		OperationalStatus_isNULL = true;
		StatusDescriptions_isNULL = true;
		Status_isNULL = true;
		HealthState_isNULL = true;
		CommunicationStatus_isNULL = true;
		DetailedStatus_isNULL = true;
		OperatingStatus_isNULL = true;
		PrimaryStatus_isNULL = true;
		EnabledState_isNULL = true;
		OtherEnabledState_isNULL = true;
		RequestedState_isNULL = true;
		EnabledDefault_isNULL = true;
		TimeOfLastStateChange_isNULL = true;
		AvailableRequestedStates_isNULL = true;
		TransitioningToState_isNULL = true;
		SystemCreationClassName_isNULL = true;
		SystemName_isNULL = true;
		CreationClassName_isNULL = true;
		Name_isNULL = true;
		PrimaryOwnerName_isNULL = true;
		PrimaryOwnerContact_isNULL = true;
		StartMode_isNULL = true;
		Started_isNULL = true;
	}
	
	~OpenDRIM_BootService() {}
	
	string getKeys() const {
		return CF_toLowCase(".SystemCreationClassName=\"" + CF_quoteString(SystemCreationClassName) + "\""".SystemName=\"" + CF_quoteString(SystemName) + "\""".CreationClassName=\"" + CF_quoteString(CreationClassName) + "\""".Name=\"" + CF_quoteString(Name) + "\"");
	}

	int getInstanceID(string& value) const {
		if (InstanceID_isNULL==true)
			return NOT_FOUND;
		value = InstanceID;
		return OK;
	}
	
	int setInstanceID(const string& newValue) {
		InstanceID = newValue;
		InstanceID_isNULL = false;
		return OK;
	}

	int getCaption(string& value) const {
		if (Caption_isNULL==true)
			return NOT_FOUND;
		value = Caption;
		return OK;
	}
	
	int setCaption(const string& newValue) {
		Caption = newValue;
		Caption_isNULL = false;
		return OK;
	}

	int getDescription(string& value) const {
		if (Description_isNULL==true)
			return NOT_FOUND;
		value = Description;
		return OK;
	}
	
	int setDescription(const string& newValue) {
		Description = newValue;
		Description_isNULL = false;
		return OK;
	}

	int getElementName(string& value) const {
		if (ElementName_isNULL==true)
			return NOT_FOUND;
		value = ElementName;
		return OK;
	}
	
	int setElementName(const string& newValue) {
		ElementName = newValue;
		ElementName_isNULL = false;
		return OK;
	}

	int getInstallDate(string& value) const {
		if (InstallDate_isNULL==true)
			return NOT_FOUND;
		value = InstallDate;
		return OK;
	}
	
	int setInstallDate(const string& newValue) {
		InstallDate = newValue;
		InstallDate_isNULL = false;
		return OK;
	}

	int getOperationalStatus(vector<unsigned short>& value) const {
		if (OperationalStatus_isNULL==true)
			return NOT_FOUND;
		value = OperationalStatus;
		return OK;
	}
	
	int setOperationalStatus(const vector<unsigned short>& newValue) {
		OperationalStatus = newValue;
		OperationalStatus_isNULL = false;
		return OK;
	}

	int getStatusDescriptions(vector<string>& value) const {
		if (StatusDescriptions_isNULL==true)
			return NOT_FOUND;
		value = StatusDescriptions;
		return OK;
	}
	
	int setStatusDescriptions(const vector<string>& newValue) {
		StatusDescriptions = newValue;
		StatusDescriptions_isNULL = false;
		return OK;
	}

	int getStatus(string& value) const {
		if (Status_isNULL==true)
			return NOT_FOUND;
		value = Status;
		return OK;
	}
	
	int setStatus(const string& newValue) {
		Status = newValue;
		Status_isNULL = false;
		return OK;
	}

	int getHealthState(unsigned short& value) const {
		if (HealthState_isNULL==true)
			return NOT_FOUND;
		value = HealthState;
		return OK;
	}
	
	int setHealthState(const unsigned short& newValue) {
		HealthState = newValue;
		HealthState_isNULL = false;
		return OK;
	}

	int getCommunicationStatus(unsigned short& value) const {
		if (CommunicationStatus_isNULL==true)
			return NOT_FOUND;
		value = CommunicationStatus;
		return OK;
	}
	
	int setCommunicationStatus(const unsigned short& newValue) {
		CommunicationStatus = newValue;
		CommunicationStatus_isNULL = false;
		return OK;
	}

	int getDetailedStatus(unsigned short& value) const {
		if (DetailedStatus_isNULL==true)
			return NOT_FOUND;
		value = DetailedStatus;
		return OK;
	}
	
	int setDetailedStatus(const unsigned short& newValue) {
		DetailedStatus = newValue;
		DetailedStatus_isNULL = false;
		return OK;
	}

	int getOperatingStatus(unsigned short& value) const {
		if (OperatingStatus_isNULL==true)
			return NOT_FOUND;
		value = OperatingStatus;
		return OK;
	}
	
	int setOperatingStatus(const unsigned short& newValue) {
		OperatingStatus = newValue;
		OperatingStatus_isNULL = false;
		return OK;
	}

	int getPrimaryStatus(unsigned short& value) const {
		if (PrimaryStatus_isNULL==true)
			return NOT_FOUND;
		value = PrimaryStatus;
		return OK;
	}
	
	int setPrimaryStatus(const unsigned short& newValue) {
		PrimaryStatus = newValue;
		PrimaryStatus_isNULL = false;
		return OK;
	}

	int getEnabledState(unsigned short& value) const {
		if (EnabledState_isNULL==true)
			return NOT_FOUND;
		value = EnabledState;
		return OK;
	}
	
	int setEnabledState(const unsigned short& newValue) {
		EnabledState = newValue;
		EnabledState_isNULL = false;
		return OK;
	}

	int getOtherEnabledState(string& value) const {
		if (OtherEnabledState_isNULL==true)
			return NOT_FOUND;
		value = OtherEnabledState;
		return OK;
	}
	
	int setOtherEnabledState(const string& newValue) {
		OtherEnabledState = newValue;
		OtherEnabledState_isNULL = false;
		return OK;
	}

	int getRequestedState(unsigned short& value) const {
		if (RequestedState_isNULL==true)
			return NOT_FOUND;
		value = RequestedState;
		return OK;
	}
	
	int setRequestedState(const unsigned short& newValue) {
		RequestedState = newValue;
		RequestedState_isNULL = false;
		return OK;
	}

	int getEnabledDefault(unsigned short& value) const {
		if (EnabledDefault_isNULL==true)
			return NOT_FOUND;
		value = EnabledDefault;
		return OK;
	}
	
	int setEnabledDefault(const unsigned short& newValue) {
		EnabledDefault = newValue;
		EnabledDefault_isNULL = false;
		return OK;
	}

	int getTimeOfLastStateChange(string& value) const {
		if (TimeOfLastStateChange_isNULL==true)
			return NOT_FOUND;
		value = TimeOfLastStateChange;
		return OK;
	}
	
	int setTimeOfLastStateChange(const string& newValue) {
		TimeOfLastStateChange = newValue;
		TimeOfLastStateChange_isNULL = false;
		return OK;
	}

	int getAvailableRequestedStates(vector<unsigned short>& value) const {
		if (AvailableRequestedStates_isNULL==true)
			return NOT_FOUND;
		value = AvailableRequestedStates;
		return OK;
	}
	
	int setAvailableRequestedStates(const vector<unsigned short>& newValue) {
		AvailableRequestedStates = newValue;
		AvailableRequestedStates_isNULL = false;
		return OK;
	}

	int getTransitioningToState(unsigned short& value) const {
		if (TransitioningToState_isNULL==true)
			return NOT_FOUND;
		value = TransitioningToState;
		return OK;
	}
	
	int setTransitioningToState(const unsigned short& newValue) {
		TransitioningToState = newValue;
		TransitioningToState_isNULL = false;
		return OK;
	}

	int getSystemCreationClassName(string& value) const {
		if (SystemCreationClassName_isNULL==true)
			return NOT_FOUND;
		value = SystemCreationClassName;
		return OK;
	}
	
	int setSystemCreationClassName(const string& newValue) {
		SystemCreationClassName = newValue;
		SystemCreationClassName_isNULL = false;
		return OK;
	}

	int getSystemName(string& value) const {
		if (SystemName_isNULL==true)
			return NOT_FOUND;
		value = SystemName;
		return OK;
	}
	
	int setSystemName(const string& newValue) {
		SystemName = newValue;
		SystemName_isNULL = false;
		return OK;
	}

	int getCreationClassName(string& value) const {
		if (CreationClassName_isNULL==true)
			return NOT_FOUND;
		value = CreationClassName;
		return OK;
	}
	
	int setCreationClassName(const string& newValue) {
		CreationClassName = newValue;
		CreationClassName_isNULL = false;
		return OK;
	}

	int getName(string& value) const {
		if (Name_isNULL==true)
			return NOT_FOUND;
		value = Name;
		return OK;
	}
	
	int setName(const string& newValue) {
		Name = newValue;
		Name_isNULL = false;
		return OK;
	}

	int getPrimaryOwnerName(string& value) const {
		if (PrimaryOwnerName_isNULL==true)
			return NOT_FOUND;
		value = PrimaryOwnerName;
		return OK;
	}
	
	int setPrimaryOwnerName(const string& newValue) {
		PrimaryOwnerName = newValue;
		PrimaryOwnerName_isNULL = false;
		return OK;
	}

	int getPrimaryOwnerContact(string& value) const {
		if (PrimaryOwnerContact_isNULL==true)
			return NOT_FOUND;
		value = PrimaryOwnerContact;
		return OK;
	}
	
	int setPrimaryOwnerContact(const string& newValue) {
		PrimaryOwnerContact = newValue;
		PrimaryOwnerContact_isNULL = false;
		return OK;
	}

	int getStartMode(string& value) const {
		if (StartMode_isNULL==true)
			return NOT_FOUND;
		value = StartMode;
		return OK;
	}
	
	int setStartMode(const string& newValue) {
		StartMode = newValue;
		StartMode_isNULL = false;
		return OK;
	}

	int getStarted(bool& value) const {
		if (Started_isNULL==true)
			return NOT_FOUND;
		value = Started;
		return OK;
	}
	
	int setStarted(const bool& newValue) {
		Started = newValue;
		Started_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_RequestStateChange_In {

public:

	unsigned short RequestedState;
	bool RequestedState_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	string TimeoutPeriod;
	bool TimeoutPeriod_isNULL;

	OpenDRIM_BootService_RequestStateChange_In() {
		RequestedState_isNULL = true;
		Job_isNULL = true;
		TimeoutPeriod_isNULL = true;
	}

	~OpenDRIM_BootService_RequestStateChange_In() {}

	int getRequestedState(unsigned short& value) const {
		if (RequestedState_isNULL == true)
			return NOT_FOUND;
		value = RequestedState;
		return OK;
	}
	int setRequestedState(const unsigned short&  newValue) {
		RequestedState = newValue;
		RequestedState_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

	int getTimeoutPeriod(string& value) const {
		if (TimeoutPeriod_isNULL == true)
			return NOT_FOUND;
		value = TimeoutPeriod;
		return OK;
	}
	int setTimeoutPeriod(const string&  newValue) {
		TimeoutPeriod = newValue;
		TimeoutPeriod_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_RequestStateChange_Out {

public:

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_RequestStateChange_Out() {
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_RequestStateChange_Out() {}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_CreateBootConfigSetting_In {

public:

	Objectpath StartingBootConfig;
	bool StartingBootConfig_isNULL;

	Objectpath ScopingComputerSystem;
	bool ScopingComputerSystem_isNULL;

	Objectpath NewBootConfig;
	bool NewBootConfig_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_CreateBootConfigSetting_In() {
		StartingBootConfig_isNULL = true;
		ScopingComputerSystem_isNULL = true;
		NewBootConfig_isNULL = true;
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_CreateBootConfigSetting_In() {}

	int getStartingBootConfig(Objectpath& value) const {
		if (StartingBootConfig_isNULL == true)
			return NOT_FOUND;
		value = StartingBootConfig;
		return OK;
	}
	int setStartingBootConfig(const Objectpath&  newValue) {
		StartingBootConfig = newValue;
		StartingBootConfig_isNULL = false;
		return OK;
	}

	int getScopingComputerSystem(Objectpath& value) const {
		if (ScopingComputerSystem_isNULL == true)
			return NOT_FOUND;
		value = ScopingComputerSystem;
		return OK;
	}
	int setScopingComputerSystem(const Objectpath&  newValue) {
		ScopingComputerSystem = newValue;
		ScopingComputerSystem_isNULL = false;
		return OK;
	}

	int getNewBootConfig(Objectpath& value) const {
		if (NewBootConfig_isNULL == true)
			return NOT_FOUND;
		value = NewBootConfig;
		return OK;
	}
	int setNewBootConfig(const Objectpath&  newValue) {
		NewBootConfig = newValue;
		NewBootConfig_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_CreateBootConfigSetting_Out {

public:

	Objectpath NewBootConfig;
	bool NewBootConfig_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_CreateBootConfigSetting_Out() {
		NewBootConfig_isNULL = true;
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_CreateBootConfigSetting_Out() {}

	int getNewBootConfig(Objectpath& value) const {
		if (NewBootConfig_isNULL == true)
			return NOT_FOUND;
		value = NewBootConfig;
		return OK;
	}
	int setNewBootConfig(const Objectpath&  newValue) {
		NewBootConfig = newValue;
		NewBootConfig_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_SetBootConfigRole_In {

public:

	Objectpath BootConfigSetting;
	bool BootConfigSetting_isNULL;

	unsigned short Role;
	bool Role_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_SetBootConfigRole_In() {
		BootConfigSetting_isNULL = true;
		Role_isNULL = true;
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_SetBootConfigRole_In() {}

	int getBootConfigSetting(Objectpath& value) const {
		if (BootConfigSetting_isNULL == true)
			return NOT_FOUND;
		value = BootConfigSetting;
		return OK;
	}
	int setBootConfigSetting(const Objectpath&  newValue) {
		BootConfigSetting = newValue;
		BootConfigSetting_isNULL = false;
		return OK;
	}

	int getRole(unsigned short& value) const {
		if (Role_isNULL == true)
			return NOT_FOUND;
		value = Role;
		return OK;
	}
	int setRole(const unsigned short&  newValue) {
		Role = newValue;
		Role_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_SetBootConfigRole_Out {

public:

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_SetBootConfigRole_Out() {
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_SetBootConfigRole_Out() {}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_SetBootConfigUsage_In {

public:

	Objectpath BootConfigSetting;
	bool BootConfigSetting_isNULL;

	Objectpath ScopingComputerSystem;
	bool ScopingComputerSystem_isNULL;

	unsigned short Role;
	bool Role_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_SetBootConfigUsage_In() {
		BootConfigSetting_isNULL = true;
		ScopingComputerSystem_isNULL = true;
		Role_isNULL = true;
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_SetBootConfigUsage_In() {}

	int getBootConfigSetting(Objectpath& value) const {
		if (BootConfigSetting_isNULL == true)
			return NOT_FOUND;
		value = BootConfigSetting;
		return OK;
	}
	int setBootConfigSetting(const Objectpath&  newValue) {
		BootConfigSetting = newValue;
		BootConfigSetting_isNULL = false;
		return OK;
	}

	int getScopingComputerSystem(Objectpath& value) const {
		if (ScopingComputerSystem_isNULL == true)
			return NOT_FOUND;
		value = ScopingComputerSystem;
		return OK;
	}
	int setScopingComputerSystem(const Objectpath&  newValue) {
		ScopingComputerSystem = newValue;
		ScopingComputerSystem_isNULL = false;
		return OK;
	}

	int getRole(unsigned short& value) const {
		if (Role_isNULL == true)
			return NOT_FOUND;
		value = Role;
		return OK;
	}
	int setRole(const unsigned short&  newValue) {
		Role = newValue;
		Role_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_SetBootConfigUsage_Out {

public:

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_SetBootConfigUsage_Out() {
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_SetBootConfigUsage_Out() {}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_ApplyBootConfigSetting_In {

public:

	Objectpath ScopingComputerSystem;
	bool ScopingComputerSystem_isNULL;

	Objectpath ApplyBootConfig;
	bool ApplyBootConfig_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_ApplyBootConfigSetting_In() {
		ScopingComputerSystem_isNULL = true;
		ApplyBootConfig_isNULL = true;
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_ApplyBootConfigSetting_In() {}

	int getScopingComputerSystem(Objectpath& value) const {
		if (ScopingComputerSystem_isNULL == true)
			return NOT_FOUND;
		value = ScopingComputerSystem;
		return OK;
	}
	int setScopingComputerSystem(const Objectpath&  newValue) {
		ScopingComputerSystem = newValue;
		ScopingComputerSystem_isNULL = false;
		return OK;
	}

	int getApplyBootConfig(Objectpath& value) const {
		if (ApplyBootConfig_isNULL == true)
			return NOT_FOUND;
		value = ApplyBootConfig;
		return OK;
	}
	int setApplyBootConfig(const Objectpath&  newValue) {
		ApplyBootConfig = newValue;
		ApplyBootConfig_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BootService_ApplyBootConfigSetting_Out {

public:

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BootService_ApplyBootConfigSetting_Out() {
		Job_isNULL = true;
	}

	~OpenDRIM_BootService_ApplyBootConfigSetting_Out() {}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

#endif /*OPENDRIM_BOOTSERVICE_H_*/
